#!/usr/bin/env python
"""
This plugin looks at the current request and determines if its coming
from a search engine. If it is, it includes code to show an
advertisement.  If not, it leave that variable blank.

The idea is only show advertisement to those that have found the site by
searching for it and not to every-day users.

You use this plugin, you must add two variables to your config.py. They
should include:

  * ad_referrer_patterns: a list of patterns (processed by the re
    module that will be used to determine if a referrer address is such
    that an ad should be shown.

  * ad_text: the text of the advert to include in the page when there is
    a matching pattern.

Examples: 

  py['ad_text'] = \"\"\"
     <script type="text/javascript"><!--
     google_ad_client = "pub-EXAMPLEKEY";
     google_ad_width = 160;
     google_ad_height = 600;
     google_ad_format = "160x600_as";
     google_ad_type = "text";
     google_ad_channel = "";
     google_color_border = "666666";
     google_color_bg = "FFFFFF";
     google_color_link = "336699";
     google_color_text = "000000";
     google_color_url = "0000ff";
     //--></script>
     <script type="text/javascript" src="http://pagead2.googlesyndication.com/pagead/show_ads.js"></script>\"\"\"

  py['ad_referrer_patterns'] = [ r'google\.com',
                                 r'yahoo\.com',
                                 r'msn\.com']

If you have questions, bug reports, or feature requests, please visit
http://mako.cc/projects/pyblosxom and contact the author.
"""
# Copyright (C) 2006 Benjamin Mako Hill <mako@atdot.cc>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
# USA

__author__      = "Benjamin Mako Hill"
__version__     = "0.1"
__url__         = "http://mako.cc/projects/pyblosxom"
__description__ = "show advertisements selectively based on referrer"

import re
import sys

def cb_prepare(args):

    data = args['request'].getData()
    http_dict = args['request'].getHttp() 
    config = args['request'].getConfiguration()

    data['ad_text'] = ''
    for pattern in config['ad_referrer_patterns']:
        if http_dict.has_key('HTTP_REFERER') and re.search(pattern, http_dict['HTTP_REFERER']):
            data['ad_text'] = config['ad_text']
            break

